==> haskell-chell-quickcheck-0.2.5.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.2
id: chell-quickcheck-0.2.5.2-z59BogoktL3dhYcuaHJjI
key: chell-quickcheck-0.2.5.2-z59BogoktL3dhYcuaHJjI
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: QuickCheck support for the Chell testing library
description:
    QuickCheck support for the <https://hackage.haskell.org/package/chell Chell> testing library.
category: Testing
abi: 8e8b3e6368d04fd4dfc5ce11efacae9b
exposed: True
exposed-modules:
    Test.Chell.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-quickcheck-0.2.5.2
hs-libraries: HSchell-quickcheck-0.2.5.2-z59BogoktL3dhYcuaHJjI
depends:
    QuickCheck-2.13.2-52gUk4jYsn5ItHsbXhjyg4 base-4.12.0.0
    chell-0.5-4V1q6UzVnjaFXi7XtZNXMR random-1.1-3ypV4EIycgb35PKjTYYr5q
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.2-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.2
id: chell-quickcheck-0.2.5.2-3fw8jxdk5FbCGJlbw4HNVE
key: chell-quickcheck-0.2.5.2-3fw8jxdk5FbCGJlbw4HNVE
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: QuickCheck support for the Chell testing library
description:
    QuickCheck support for the <https://hackage.haskell.org/package/chell Chell> testing library.
category: Testing
abi: 7ce9571f5504640d5876b14ad6073ad8
exposed: True
exposed-modules:
    Test.Chell.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-quickcheck-0.2.5.2
hs-libraries: HSchell-quickcheck-0.2.5.2-3fw8jxdk5FbCGJlbw4HNVE
depends:
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
    chell-0.5-LZydtUFHE5SIUkeBUfbgJj random-1.1-3ypV4EIycgb35PKjTYYr5q
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
